@@ -18,6 +18,8 @@
 #include <PlasmaScreencastV1Session.h>
 #endif
 
+#include "VideoStream.h"
+
 class SessionWrapper : public QObject
 {
     Q_OBJECT
@@ -94,23 +96,6 @@ SessionController::SessionController(KRdp::Server *server, SessionType sessionTy
     connect(quitAction, &QAction::triggered, this, &SessionController::stopFromSNI);
     menu->addAction(quitAction);
     m_sni->setContextMenu(menu);
-
-    // Create a single temporary session to request permissions from the portal
-    // on startup.
-    if (sessionType == SessionType::Portal) {
-        m_initializationSession = makeSession();
-
-        auto cleanup = [this]() {
-            auto session = m_initializationSession.release();
-            session->deleteLater();
-        };
-
-        // Destroy the session after we've successfully connected, we just use
-        // it to get permissions. Reusing it is going to lead to problems with
-        // reconnection.
-        connect(m_initializationSession.get(), &KRdp::AbstractSession::started, this, cleanup);
-        connect(m_initializationSession.get(), &KRdp::AbstractSession::error, this, cleanup);
-    }
 }
 
 SessionController::~SessionController() noexcept
@@ -175,11 +160,11 @@ std::unique_ptr<KRdp::AbstractSession> SessionController::makeSession()
 {
 #ifdef WITH_PLASMA_SESSION
     if (m_sessionType == SessionType::Plasma) {
-        return std::make_unique<KRdp::PlasmaScreencastV1Session>(m_server);
+        return std::make_unique<KRdp::PlasmaScreencastV1Session>();
     } else
 #endif
     {
-        return std::make_unique<KRdp::PortalSession>(m_server);
+        return std::make_unique<KRdp::PortalSession>();
     }
 }
 
